blamf
#####
Just testing some python packaging principles.

``pip install -r requirements.txt``

Blah

``pip install pipenv versioneer pytest coverage pytest-cov collective.checkdocs pygments twine``

Blah
